# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib import admin
from django.utils.translation import ugettext as _

from jmb.jadmin.options import JumboModelAdmin

from thux.carriage.models import Carriage, Delivery


class CarriageAdmin(JumboModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_('general information'), {
            'fields': ('code', 'name', 'slug', 'description',),
        }),
    )
    search_fields = ('code', 'name')
    list_display = (
        'get_status_icon', 'code', 'name', 'description',
        'get_edit_icon', 'get_delete_icon'
    )
    prepopulated_fields = {"slug": ("name",)}


class DeliveryAdmin(JumboModelAdmin):
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_('general information'), {
            'fields': ('status', 'transport_by', 'carriage',),
        }),
    )
    search_fields = ('transport_by', 'carriage')
    list_display = (
        'get_status_icon', 'transport_by', 'carriage',
        'get_edit_icon', 'get_delete_icon'
    )


admin.site.register(Delivery, DeliveryAdmin)
admin.site.register(Carriage, CarriageAdmin)
