# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


class Carriage(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Stores carriages:
    frw - CARRIAGE FORWARD - PORTO ASSEGNATO
    pad - CARRIAGE PAID - PORTO FRANCO
    exw - EX WORKS" - EX WORKS
    pdc - CARRIAGE PAID W/CHARGE - PORTO FRANCO CON ADDEBITO
    """
    code = models.CharField(
        primary_key=True,
        max_length=3,
        verbose_name=_("code")
    )
    name = models.CharField(
        max_length=50,
        verbose_name=_("name")
    )
    slug = models.SlugField(
        db_index=True,
        max_length=50,
        verbose_name=_("slug"),
        help_text=_("used for URLs, auto-generated from name if blank"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("description")
    )

    class Meta:
        verbose_name = _('carriage')
        verbose_name_plural = _('carriages')
        ordering = ('ordering', 'name')

    def __unicode__(self):
        return self.name


class Delivery(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Stores deliveries
    """
    code = models.CharField(
        primary_key=True,
        max_length=3,
        verbose_name=_("code")
    )
    transport_by = models.CharField(
        max_length=3,
        choices=settings.CARRIAGE_TRANSPORTBY_DEF,
        verbose_name=_('transport by'),
    )
    carriage = models.ForeignKey(
        Carriage,
        verbose_name=_('carriage'),
    )

    class Meta:
        verbose_name = _('delivery')
        verbose_name_plural = _('deliveries')
        ordering = ('ordering', 'transport_by', 'carriage')

    def __unicode__(self):
        return u"{transport_by} - {carriage}".format(
            transport_by=self.get_transport_by_display(),
            carriage=self.carriage,
        )
